summaryrefslogtreecommitdiffstats
path: root/languages/cpp/app_templates/opieapplet/simpleimpl.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'languages/cpp/app_templates/opieapplet/simpleimpl.cpp')
-rw-r--r--languages/cpp/app_templates/opieapplet/simpleimpl.cpp30
1 files changed, 15 insertions, 15 deletions
diff --git a/languages/cpp/app_templates/opieapplet/simpleimpl.cpp b/languages/cpp/app_templates/opieapplet/simpleimpl.cpp
index 3264314c..cc2a6a17 100644
--- a/languages/cpp/app_templates/opieapplet/simpleimpl.cpp
+++ b/languages/cpp/app_templates/opieapplet/simpleimpl.cpp
@@ -2,14 +2,14 @@
#include <tqpainter.h>
#include <tqmessagebox.h>
-#include <qpe/applnk.h> // for AppLnk
-#include <qpe/resource.h> // for Resource loading
+#include <tqpe/applnk.h> // for AppLnk
+#include <tqpe/resource.h> // for Resource loading
#include "%{APPNAMELC}.h"
-%{APPNAME}::%{APPNAME}(TQWidget *parent)
- : TQWidget( parent, "%{APPNAME} Applet" ) {
+%{APPNAME}::%{APPNAME}(TQWidget *tqparent)
+ : TQWidget( tqparent, "%{APPNAME} Applet" ) {
/*
* we will load an Image, scale it for the right usage
* remember your applet might be used by different
@@ -79,7 +79,7 @@ void %{APPNAME}::paintEvent( TQPaintEvent* ) {
%{APPNAME}Impl::~%{APPNAME}Impl() {
/*
* we will delete our applets as well
- * setAUtoDelete makes the QList free
+ * setAUtoDelete makes the TQList free
* the objects behind the pointers
*/
m_applets.setAutoDelete( true );
@@ -89,12 +89,12 @@ void %{APPNAME}::paintEvent( TQPaintEvent* ) {
/*
* For the taskbar interface return a Widget
*/
-TQWidget* %{APPNAME}Impl::applet( TQWidget* parent ) {
+TQWidget* %{APPNAME}Impl::applet( TQWidget* tqparent ) {
/*
* There are problems with ownership. So we add
* our ownlist and clear this;
*/
- %{APPNAME}* ap = new %{APPNAME}( parent );
+ %{APPNAME}* ap = new %{APPNAME}( tqparent );
m_applets.append( ap );
return ap;
@@ -109,12 +109,12 @@ int %{APPNAME}Impl::position()const {
/*
- * Now the important QUnkownInterface method without
+ * Now the important TQUnkownInterface method without
* this one your applet won't load
* @param uuid The uuid of the interface
* @param iface The pointer to the interface ptr
*/
-QRESULT %{APPNAME}Impl::queryInterface( const QUuid& uuid, QUnknownInterface** iface) {
+TQRESULT %{APPNAME}Impl::queryInterface( const TQUuid& uuid, TQUnknownInterface** iface) {
/* set the pointer to the interface to 0 */
*iface = 0;
@@ -128,24 +128,24 @@ QRESULT %{APPNAME}Impl::queryInterface( const QUuid& uuid, QUnknownInterface** i
* Now the caller knows that the Interface Pointer
* is valid and the interface supported
*/
- if ( uuid == IID_QUnknown )
+ if ( uuid == IID_TQUnknown )
*iface = this;
else if ( uuid == IID_TaskbarApplet )
*iface = this;
else
- return QS_FALSE;
+ return TQS_FALSE;
if ( *iface )
(*iface)->addRef();
- return QS_OK;
+ return TQS_OK;
}
/*
* Finally we need to export the Interface.
* CREATE_INSTANCE creates a interface and calls
* queryInterface for the QUnknownInterface once
* With out this function the applet can't be loaded.
*
* NOTE: If your applet does not load it's likely you've an
@@ -156,7 +156,7 @@ QRESULT %{APPNAME}Impl::queryInterface( const QUuid& uuid, QUnknownInterface** i
* The main(int argc, char* argv[] ) does not need to be
* included in a library so it's ok that the linker complains
*/
-Q_EXPORT_INTERFACE() {
- Q_CREATE_INSTANCE( %{APPNAME}Impl )
+TQ_EXPORT_INTERFACE() {
+ TQ_CREATE_INSTANCE( %{APPNAME}Impl )
}
@@ -128,24 +128,24 @@ QRESULT %{APPNAME}Impl::queryInterface( const QUuid& uuid, QUnknownInterface** i
* Finally we need to export the Interface.
* CREATE_INSTANCE creates a interface and calls
- * queryInterface for the QUnknownInterface once
+ * queryInterface for the TQUnknownInterface once
* With out this function the applet can't be loaded.
*